@@ -9,7 +9,7 @@
     <message>
         <location filename="mainwindow.ui" line="46"/>
         <source>Quit application</source>
-        <translation>Sair da aplicação</translation>
+        <translation>Sair do aplicativo</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="49"/>
@@ -66,17 +66,17 @@
         <location filename="mainwindow.cpp" line="462"/>
         <location filename="mainwindow.cpp" line="481"/>
         <source>Select ISO</source>
-        <translation>Selecione o arquivo ISO</translation>
+        <translation>Selecionar o arquivo ISO</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="250"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selecione o Dispositivo USB  de Destino&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selecionar o Dispositivo USB  de Destino&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="260"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selecione o arquivo ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selecionar o arquivo ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="289"/>
@@ -86,17 +86,17 @@
     <message>
         <location filename="mainwindow.ui" line="307"/>
         <source>Make the ext4 filesystem even if one exists</source>
-        <translation>Formate em ext4 mesmo que já esteja formatado nesse sistema de arquivos</translation>
+        <translation>Formatar em ext4 mesmo que já esteja formatado neste sistema de arquivos</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="314"/>
         <source>Save the original boot directory when updating a live-usb</source>
-        <translation>Salve o diretório original de inicialização (boot) ao atualizar o USB Executável</translation>
+        <translation>Salvar o diretório original de inicialização (boot) ao atualizar o USB Executável</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="321"/>
         <source>Use gpt partitioning instead of msdos</source>
-        <translation>Use o particionamento gpt em vez de msdos</translation>
+        <translation>Usar o particionamento gpt em vez de msdos</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="324"/>
@@ -106,7 +106,7 @@
     <message>
         <location filename="mainwindow.ui" line="331"/>
         <source>Update (only update an existing live-usb)</source>
-        <translation>Atualizar (apenas o USB Executável existente)</translation>
+        <translation>Atualizar (apenas atualiza o USB Executável existente)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="338"/>
@@ -121,7 +121,7 @@
     <message>
         <location filename="mainwindow.ui" line="348"/>
         <source>Ignore USB/removable check</source>
-        <translation>Ignorar a verificação USB/removível</translation>
+        <translation>Ignorar a verificação do USB/removível</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="355"/>
@@ -131,17 +131,17 @@
     <message>
         <location filename="mainwindow.ui" line="365"/>
         <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
-        <translation>Definir o marcador (flag) de disco &apos;pmbr_boot&apos; (não inicializa via UEFI)</translation>
+        <translation>Definir o marcador (flag) de disco ‘pmbr_boot’ (não inicializa via UEFI)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="372"/>
         <source>Don&apos;t use fuseiso to mount iso files</source>
-        <translation>Não use o fuseiso para montar arquivos ISO</translation>
+        <translation>Não usar o fuseiso para montar arquivos ISO</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="398"/>
         <source>Size of ESP (uefi) partition:</source>
-        <translation>Tamanho da partição ESP (uefi):</translation>
+        <translation>Tamanho da partição ESP (UEFI):</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="418"/>
@@ -171,7 +171,7 @@
     <message>
         <location filename="mainwindow.ui" line="493"/>
         <source>Make separate data partition (percent)</source>
-        <translation>Crie a partição de dados separada (percentagem)</translation>
+        <translation>Criar a partição de dados separada (em porcentagem)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="500"/>
@@ -187,7 +187,7 @@
         <location filename="mainwindow.ui" line="524"/>
         <location filename="mainwindow.cpp" line="407"/>
         <source>Show advanced options</source>
-        <translation>Mostrar opções avançadas</translation>
+        <translation>Exibir as opções avançadas</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="544"/>
@@ -197,22 +197,22 @@
     <message>
         <location filename="mainwindow.ui" line="559"/>
         <source>Full-featured mode - writable LiveUSB</source>
-        <translation>Modo completo - LiveUSB gravável</translation>
+        <translation>Modo completo - USB Executável (LiveUSB) gravável</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="569"/>
         <source>Read-only, cannot be used with persistency</source>
-        <translation>Somente leitura, não pode ser usado com &apos;persistência&apos;</translation>
+        <translation>Somente leitura, não pode ser utilizado com a ‘persistência’</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="572"/>
         <source>Image mode - read-only LiveUSB (dd)</source>
-        <translation>Modo de imagem - somente leitura LiveUSB (dd)</translation>
+        <translation>Modo de imagem - somente leitura USB Executável (LiveUSB) (dd)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="586"/>
         <source>For distros other than antiX/MX use image mode (dd).</source>
-        <translation>Para distribuições (distros) que não sejam antiX / MX, use o modo de imagem (dd).</translation>
+        <translation>Para distribuições (distros) que não sejam o antiX ou o MX Linux, use o modo de imagem (dd).</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="634"/>
@@ -222,7 +222,7 @@
     <message>
         <location filename="mainwindow.ui" line="669"/>
         <source>Percent of USB-device to use:</source>
-        <translation>Percentagem do dispositivo USB a ser usado:</translation>
+        <translation>Porcentagem do dispositivo USB a ser utilizado:</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="676"/>
@@ -232,7 +232,7 @@
     <message>
         <location filename="mainwindow.ui" line="724"/>
         <source>Don&apos;t run commands that affect the usb device</source>
-        <translation>Não execute comandos que afetem o dispositivo USB</translation>
+        <translation>Não executar os comandos que afetem o dispositivo USB</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="727"/>
@@ -242,7 +242,7 @@
     <message>
         <location filename="mainwindow.ui" line="734"/>
         <source>clone from a mounted live-usb or iso-file.</source>
-        <translation>clonar a partir de USB Executável ou arquivo ISO montado.</translation>
+        <translation>clonar a partir do USB Executável ou do arquivo ISO montado.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="737"/>
@@ -252,7 +252,7 @@
     <message>
         <location filename="mainwindow.ui" line="744"/>
         <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
-        <translation>Configurar para inicializar a partir de uma partição criptografada, solicitará a frase secreta/senha na primeira inicialização</translation>
+        <translation>Configurar para inicializar a partir de uma partição criptografada/encriptada, solicitará a frase-senha (senha) na primeira inicialização</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="747"/>
@@ -274,14 +274,14 @@
     <message>
         <location filename="mainwindow.cpp" line="86"/>
         <source>Source and destination are on the same device, please select again.</source>
-        <translation>A origem e o destino estão no mesmo dispositivo, selecionar novamente.</translation>
+        <translation>A origem e o destino estão no mesmo dispositivo, por favor, selecione novamente.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="111"/>
         <source>Writing %1 using 'dd' command to /dev/%2,
 
 Please wait until the the process is completed</source>
-        <translation>Gravando %1, usando o comando &apos;dd&apos; em /dev/%2.
+        <translation>Gravando %1, utilizando o comando ‘dd’ em /dev/%2.
 
 Por favor, espere até que o processo seja concluído</translation>
     </message>
@@ -293,12 +293,12 @@ Por favor, espere até que o processo seja concluído</translation>
     <message>
         <location filename="mainwindow.cpp" line="265"/>
         <source>LiveUSB creation successful!</source>
-        <translation>Instalação externa USB criada com sucesso!</translation>
+        <translation>A instalação externa do USB Executável foi criada com sucesso!</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="267"/>
         <source>Error encountered in the LiveUSB creation process</source>
-        <translation>Erro no processo de criação da instalação externa USB Executável</translation>
+        <translation>Erro no processo de criação da instalação externa do USB Executável</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="316"/>
@@ -329,7 +329,7 @@ Por favor, espere até que o processo seja concluído</translation>
     <message>
         <location filename="mainwindow.cpp" line="357"/>
         <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
-        <translation>Programa para criar instalações externas USB Executável a partir de arquivos ISO, de outra instalação externa USB Executável, de CD/DVD Executável ou de um sistema em execução.</translation>
+        <translation>Programa para criar instalações externas USB Executável (Live USB) a partir de arquivos ISO, de outra instalação externa USB Executável, de CD/DVD Executável (Live CD/DVD) ou de um sistema externo em execução (Live).</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="359"/>
@@ -349,13 +349,13 @@ Por favor, espere até que o processo seja concluído</translation>
     <message>
         <location filename="mainwindow.cpp" line="379"/>
         <source>Select an ISO file to write to the USB drive</source>
-        <translation>Selecione um arquivo ISO para instalar no dispositivo USB</translation>
+        <translation>Selecionar um arquivo ISO para instalar no dispositivo USB</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="387"/>
         <location filename="mainwindow.cpp" line="458"/>
         <source>Select Source Directory</source>
-        <translation>Selecione o Diretório de Origem</translation>
+        <translation>Selecionar o Diretório de Origem</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="392"/>
@@ -365,19 +365,19 @@ Por favor, espere até que o processo seja concluído</translation>
     <message>
         <location filename="mainwindow.cpp" line="413"/>
         <source>Hide advanced options</source>
-        <translation>Ocultar opções avançadas</translation>
+        <translation>Ocultar as opções avançadas</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="457"/>
         <location filename="mainwindow.cpp" line="473"/>
         <source>Select Source</source>
-        <translation>Selecione a Origem</translation>
+        <translation>Selecionar a Origem</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="461"/>
         <location filename="mainwindow.cpp" line="479"/>
         <source>Select ISO file</source>
-        <translation>Selecione o arquivo ISO</translation>
+        <translation>Selecionar o arquivo ISO</translation>
     </message>
 </context>
 <context>
@@ -406,7 +406,7 @@ Por favor, espere até que o processo seja concluído</translation>
     <message>
         <location filename="main.cpp" line="75"/>
         <source>You must run this program as root.</source>
-        <translation>Você tem que executar este programa como administrador (root).</translation>
+        <translation>Você tem que executar este programa como root (administrador).</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
